@@ -36,7 +36,7 @@ else:
     input_ = input
 
 
-__version__ = '0.1.0'
+__version__ = '0.1.2'
 __author__ = 'pahaz'
 
 
@@ -271,8 +271,8 @@ def _remove_none_values(dictionary):
 class BaseSSHTunnelForwarderError(Exception):
     """ Exception raised by :class:`SSHTunnelForwarder` errors """
 
-    def __init__(self, value, *args, **kwargs):
-        self.value = value
+    def __init__(self, *args, **kwargs):
+        self.value = kwargs.pop('value', args[0] if args else '')
 
     def __str__(self):
         return self.value
@@ -741,7 +741,7 @@ class SSHTunnelForwarder(object):
             self.skip_tunnel_checkup = False
             self.check_tunnels()
             self.skip_tunnel_checkup = True  # roll it back
-        return self.tunnel_is_up(target)
+        return self.tunnel_is_up.get(target, True)
 
     def _make_ssh_forward_handler_class(self, remote_address_):
         """
@@ -778,6 +778,7 @@ class SSHTunnelForwarder(object):
             )
 
             if ssh_forward_server:
+                ssh_forward_server.daemon_threads = self.daemon_forward_servers
                 self._server_list.append(ssh_forward_server)
                 self.tunnel_is_up[ssh_forward_server.server_address] = False
             else:
@@ -1015,9 +1016,10 @@ class SSHTunnelForwarder(object):
             ssh_loaded_pkeys = []
 
         if isinstance(ssh_pkey, string_types):
-            if os.path.exists(ssh_pkey):
+            ssh_pkey_expanded = os.path.expanduser(ssh_pkey)
+            if os.path.exists(ssh_pkey_expanded):
                 ssh_pkey = SSHTunnelForwarder.read_private_key_file(
-                    pkey_file=ssh_pkey,
+                    pkey_file=ssh_pkey_expanded,
                     pkey_password=ssh_pkey_password or ssh_password,
                     logger=logger
                 )
@@ -1079,7 +1081,7 @@ class SSHTunnelForwarder(object):
             try:
                 self._make_ssh_forward_server(rem, loc)
             except BaseSSHTunnelForwarderError as e:
-                msg = 'Problem setting SSH Forwarder up: {0}'.format(e.args[0])
+                msg = 'Problem setting SSH Forwarder up: {0}'.format(e.value)
                 self.logger.error(msg)
 
     @staticmethod
@@ -1184,7 +1186,9 @@ class SSHTunnelForwarder(object):
         s.settimeout(TUNNEL_TIMEOUT)
         try:
             # Windows raises WinError 10049 if trying to connect to 0.0.0.0
-            s.connect(('127.0.0.1', _srv.local_port))
+            connect_to = ('127.0.0.1', _srv.local_port) \
+                if _srv.local_host == '0.0.0.0' else _srv.local_address
+            s.connect(connect_to)
             self.tunnel_is_up[_srv.local_address] = _srv.tunnel_ok.get(
                 timeout=TUNNEL_TIMEOUT * 1.1
             )
@@ -1420,7 +1424,7 @@ class SSHTunnelForwarder(object):
         """ Return True if the underlying SSH transport is up """
         if (
             '_transport' in self.__dict__ and
-            self._transport.is_authenticated()
+            self._transport.is_active()
         ):
             return True
         return False
@@ -1766,5 +1770,6 @@ def _cli_main(args=None):
 
             ''')
 
+
 if __name__ == '__main__':  # pragma: no cover
     _cli_main()
